@@ -1,11 +1,13 @@
 library(circlize)
 
+op = par(no.readonly = TRUE)
+
 layout(rbind(c(1,1,2,2), c(0, 3, 3,0)))
 par(mar = c(2, 2, 2, 2))
 factors = letters[1:4]
 circos.initialize(factors = factors, xlim = c(0, 1))
 circos.trackPlotRegion(ylim = c(0, 1), panel.fun = function(x, y) {
-    circos.text(0.5, 0.5, "outer circos")
+    circos.text(0.5, 0.5, "outer circos", niceFacing = TRUE)
 })
 circos.clear()
 box()
@@ -16,7 +18,7 @@ circos.par("canvas.xlim" = c(-2, 2), "canvas.ylim" = c(-2, 2))
 factors = letters[1:3]
 circos.initialize(factors = factors, xlim = c(0, 1))
 circos.trackPlotRegion(ylim = c(0, 1), panel.fun = function(x, y) {
-    circos.text(0.5, 0.5, "inner circos")
+    circos.text(0.5, 0.5, "inner circos", niceFacing = TRUE)
 })
 circos.clear()
 box()
@@ -26,7 +28,7 @@ axis(side = 2)
 factors = letters[1:4]
 circos.initialize(factors = factors, xlim = c(0, 1))
 circos.trackPlotRegion(ylim = c(0, 1), panel.fun = function(x, y) {
-    circos.text(0.5, 0.5, "outer circos")
+    circos.text(0.5, 0.5, "outer circos", niceFacing = TRUE)
 })
 circos.clear()
 
@@ -35,6 +37,8 @@ circos.par("canvas.xlim" = c(-2, 2), "canvas.ylim" = c(-2, 2))
 factors = letters[1:3]
 circos.initialize(factors = factors, xlim = c(0, 1))
 circos.trackPlotRegion(ylim = c(0, 1), panel.fun = function(x, y) {
-    circos.text(0.5, 0.5, "inner circos")
+    circos.text(0.5, 0.5, "inner circos", niceFacing = TRUE)
 })
-circos.clear()
\ No newline at end of file
+circos.clear()
+
+par(op)
